
.. toctree::
   :hidden:

   Home page <self>
   Setup <setup>
   Get Started <notebooks/quickstart>
   API reference <_autosummary/connect>


Connect
=======
 
Connect is a utility module that integrates ML assessments with the Credo AI Governance Platform.
Connect defines `evidence_containers` which function as adapters between diverse AI assessment
frameworks (or custom analyses) and Credo AI-compatible `Evidence` objects.


